@@ -2,15 +2,17 @@
 #'
 #' Ensemble sparse partial least squares regression.
 #'
-#' @param x predictor matrix
-#' @param y response vector
-#' @param maxcomp Maximum number of components included within the models,
-#' if not specified, default is 5.
+#' @param x Predictor matrix.
+#' @param y Response vector.
+#' @param maxcomp Maximum number of components included within each model.
+#' If not specified, will use 5 by default.
 #' @param alpha Parameter (grid) controlling sparsity of the model.
 #' If not specified, default is \code{seq(0.2, 0.8, 0.2)}.
-#' @param MCtimes times of Monte-Carlo
-#' @param method \code{"mc"} or \code{"bootstrap"}. Default is \code{"mc"}.
-#' @param ratio sample ratio used when \code{method = "mc"}
+#' @param reptimes Number of models to build with Monte-Carlo resampling
+#' or bootstrapping.
+#' @param method Resampling method. \code{"mc"} (Monte-Carlo resampling)
+#' or \code{"boot"} (bootstrapping). Default is \code{"mc"}.
+#' @param ratio Sampling ratio used when \code{method = "mc"}.
 #' @param parallel Integer. Number of CPU cores to use.
 #' Default is \code{1} (not parallelized).
 #'
@@ -18,10 +20,10 @@
 #'
 #' @author Nan Xiao <\url{http://nanx.me}>
 #'
-#' @seealso See \code{\link{enspls.fs}} for feature selection with ensemble
-#' sparse partial least squares regression.
+#' @seealso See \code{\link{enspls.fs}} for measuring feature importance
+#' with ensemble sparse partial least squares regressions.
 #' See \code{\link{enspls.od}} for outlier detection with ensemble
-#' sparse partial least squares regression.
+#' sparse partial least squares regressions.
 #'
 #' @export enspls.fit
 #'
@@ -34,15 +36,15 @@
 #' y = logd1k$y
 #'
 #' set.seed(42)
-#' fit = enspls.fit(x, y, MCtimes = 4, maxcomp = 3)
+#' fit = enspls.fit(x, y, reptimes = 4, maxcomp = 3)
 #' print(fit)
 #' predict(fit, newx = x)
 
 enspls.fit = function(x, y,
                       maxcomp = 5L,
                       alpha = seq(0.2, 0.8, 0.2),
-                      MCtimes = 500L,
-                      method = c('mc', 'bootstrap'), ratio = 0.8,
+                      reptimes = 500L,
+                      method = c('mc', 'boot'), ratio = 0.8,
                       parallel = 1L) {
 
   if (missing(x) | missing(y)) stop('Please specify both x and y')
@@ -50,20 +52,20 @@ enspls.fit = function(x, y,
   method = match.arg(method)
 
   x.row = nrow(x)
-  samp.idx = vector('list', MCtimes)
+  samp.idx = vector('list', reptimes)
 
   if (method == 'mc') {
-    for (i in 1L:MCtimes) samp.idx[[i]] = sample(1L:x.row, round(x.row * ratio))
+    for (i in 1L:reptimes) samp.idx[[i]] = sample(1L:x.row, round(x.row * ratio))
   }
 
-  if (method == 'bootstrap') {
-    for (i in 1L:MCtimes) samp.idx[[i]] = sample(1L:x.row, x.row, replace = TRUE)
+  if (method == 'boot') {
+    for (i in 1L:reptimes) samp.idx[[i]] = sample(1L:x.row, x.row, replace = TRUE)
   }
 
   if (parallel < 1.5) {
 
-    modellist = vector('list', MCtimes)
-    for (i in 1L:MCtimes) {
+    modellist = vector('list', reptimes)
+    for (i in 1L:reptimes) {
       xtmp = x[samp.idx[[i]], ]
       ytmp = y[samp.idx[[i]]]
       modellist[[i]] = enspls.fit.core(xtmp, ytmp, maxcomp, alpha)
@@ -72,7 +74,7 @@ enspls.fit = function(x, y,
   } else {
 
     registerDoParallel(parallel)
-    modellist = foreach(i = 1L:MCtimes) %dopar% {
+    modellist = foreach(i = 1L:reptimes) %dopar% {
       xtmp = x[samp.idx[[i]], ]
       ytmp = y[samp.idx[[i]]]
       enspls.fit.core(xtmp, ytmp, maxcomp, alpha)
